@@ -5,13 +5,20 @@ use 5.008004;
 use strict;
 use warnings;
 
-our $VERSION = '0.12_02';
+our $VERSION = '0.13_01';
 
 use DateTime 0.1402;
 use DateTime::Calendar::Julian 0.04;
 
 use Carp ();
 
+# We're relying on DateTime's validation, but we want Carp to report
+# errors against our caller, not ourselves. Ditto
+# DateTime::Calendar::Julian
+our @CARP_NOT = (
+    qw{ DateTime DateTime::Duration DateTime::Calendar::Julian },
+);
+
 use overload ( 'fallback' => 1,
                '<=>' => '_compare_overload',
                'cmp' => '_compare_overload',
@@ -603,6 +610,20 @@ for my $sub (
 		week_of_month
 		weekday_of_month
 		/,
+		# Missed in the above somehow --TRW
+		qw/
+		day_of_quarter
+		day_of_quarter_0
+		is_between
+		is_last_day_of_month
+		is_last_day_of_quarter
+		is_last_day_of_year
+		month_length
+		quarter_length
+		rfc3339
+		stringify
+		year_length
+		/,
 ) {
     no strict 'refs';
     *$sub = sub {
@@ -852,6 +873,8 @@ leap year in the Julian calendar but not the Gregorian calendar.
 
 =item * julian_deviation( [$datetime] )
 
+This method was added in version 0.13.
+
 This method returns the difference in days between the Gregorian and the
 Julian calendar. If the parameter $datetime is given, it will be used to
 calculate the result; in this case this method can be used as a class
